from distutils.core import setup
setup(
        name        ='yhwNester',
        version     ='1.0.2',
        py_modules  =['yhwNester'],        #將模組的中介資料關聯到setup函式的引數
        author      ='yhw',
        author_email='yuhung.tw@icloud.com',
        url         ='http://www.yuhung.tw',
        description ='A sample module',
     )
